<?php

/**
 * @file
 * Contains \Drupal\ivw_integration\Form\SettingsForm.
 */

namespace Drupal\ivw_integration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Utility\Token;

/**
 * Defines a form that configures ivw settings.
 */
class SettingsForm extends ConfigFormBase {
  /**
   * The token object.
   *
   * @var Token
   */
  protected $token = array();

   /**
   * Constructs a \Drupal\ivw_integration\SettingsForm object.
   *
   * @param ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
    * @param Token $token
    *   The token object.
   */
  public function __construct(ConfigFactoryInterface $config_factory, Token $token){
    parent::__construct($config_factory);
    $this->token = $token;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('token')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ivw_integration_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $ivw_integration_settings = $this->config('ivw_integration.settings');
    $form['current_code'] = array(
      '#markup' => 'Current Default Code: ' . $this->token->replace($ivw_integration_settings->get('code_template'), array(), array('sanitize' => FALSE)),
    );

    $form['ivw_settings'] = array(
      '#type' => 'vertical_tabs',
      '#default_tab' => 'site_settings',
    );

    $form['site_settings'] = array(
      '#type' => 'details',
      '#title' => t('Site settings'),
      '#open' => TRUE,
      '#group' => 'ivw_settings',
    );

    $form['site_settings']['site'] = array(
      '#type' => 'textfield',
      '#title' => t('IVW Site name'),
      '#required' => TRUE,
      '#default_value' => $ivw_integration_settings->get('site'),
      '#description' => t('Site name as given by IVW, this is used as default for the "st" parameter in the iam_data object')
    );
    $form['site_settings']['mobile_site'] = array(
      '#type' => 'textfield',
      '#title' => t('IVW Mobile Site name'),
      '#required' => TRUE,
      '#default_value' => $ivw_integration_settings->get('mobile_site'),
      '#description' => t('Mobile site name as given by IVW, this is used as default for the "st" parameter in the iam_data object')
    );
    $form['site_settings']['code_template'] = array(
      '#type' => 'textfield',
      '#title' => t('Code template'),
      '#required' => TRUE,
      '#maxlength' => 512,
      '#size' => 128,
      '#default_value' => $ivw_integration_settings->get('code_template'),
      '#description' => t('Code template, for creating the actual ivw code.'),
    );

    $form['site_settings']['code_template_token_tree'] = array(
      '#theme' => 'token_tree',
      '#token_types' => ['ivw'],
    );

    $form['site_settings']['responsive'] = array(
      '#type' => 'checkbox',
      '#title' => t('Site is responsive'),
      '#required' => TRUE,
      '#default_value' => $ivw_integration_settings->get('responsive'),
      '#description' => t('Responsive sites must handle mobile code in javascript, this is activated here.')
    );

    $form['site_settings']['mobile_width'] = array(
      '#type' => 'textfield',
      '#states' => array(
        // Hide the setting when site is not flagged as responsive.
        'invisible' => array(
          ':input[name="ivw_responsive"]' => array('checked' => FALSE),
        ),
      ),
      '#title' => t('Mobile width'),
      '#required' => TRUE,
      '#default_value' => $ivw_integration_settings->get('mobile_width'),
      '#description' => t('On a responsive site, this value tells the javascript up to which screen width, the device should be treated as mobile.')
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('ivw_integration.settings')
      ->set('site', $values['site'])
      ->set('mobile_site', $values['mobile_site'])
      ->set('code_template', $values['code_template'])
      ->set('responsive', $values['responsive'])
      ->set('mobile_width', $values['mobile_width'])
      ->save();
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'ivw_integration.settings',
    ];
  }
}
